/*
 * Copyright (c) 2000 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __SHORTCUT_INTERNAL_DEF_H__
#define __SHORTCUT_INTERNAL_DEF_H__

#include <gio/gio.h>
#include <glib.h>
#include "shortcut.h"
#include "shortcut_manager.h"
#include "shortcut_error.h"

#ifndef EXPORT_API
#define EXPORT_API __attribute__ ((visibility("default")))
#endif

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * @addtogroup SHORTCUT_INTERNAL
 * @{
 */

struct result_cb_item {
	result_internal_cb_t result_internal_cb;
	result_cb_t result_cb;
	void *data;
};

int _dbus_init(void);
int _dbus_signal_init();
char *_shortcut_get_pkgname_by_pid(void);
int _send_sync_shortcut(GVariant *body, GDBusMessage **reply, char *cmd);
int _send_service_register();
int _send_async_shortcut(GVariant *body, struct result_cb_item *cb_item, char *cmd);
int _check_privilege(void);
void _set_request_cb(shortcut_request_cb request_cb, void *data);
void _set_remove_cb(shortcut_remove_cb remove_cb, void *data);
void _unset_request_cb(void);
void _unset_remove_cb(void);
int _dbus_set_watch_name();

/**
 * @}
 */


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __SHORTCUT_INTERNAL_DEF_H__ */

